.. _install:

Installing the illumio Library
==============================

To get started with the **illumio** library, install it from PyPI or from source.

You can find the `latest release here <https://github.com/illumio/illumio-py/releases/latest>`_.

Using pip
---------

The simplest approach is to run the following::

    $ python -m pip install illumio

From Source
-----------

The **illumio** library is maintained in the official Illumio organization
`on GitHub <https://github.com/illumio/illumio-py>`_.

You can clone the repository directly::

    $ git clone git://github.com/illumio/illumio-py.git

Or download the source trunk as a tarball::

    $ curl -OL https://github.com/illumio/illumio-py/tarball/main

From the source root, run the following to install locally::

    $ python -m pip install .
